summaryrefslogtreecommitdiff
path: root/regex.c
diff options
context:
space:
mode:
Diffstat (limited to 'regex.c')
-rw-r--r--regex.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/regex.c b/regex.c
index f121d48db2..694299daf9 100644
--- a/regex.c
+++ b/regex.c
@@ -3412,7 +3412,7 @@ re_search(bufp, string, size, startpos, range, regs)
\
*stackp++ = pattern_place; \
*stackp++ = string_place; \
*stackp++ = (unsigned char*)options; /* current option status */ \
*stackp++ = (unsigned char*)0; /* non-greedy flag */ \
} while(0)
@@ -4293,7 +4293,7 @@ re_match(bufp, string_arg, size, pos, regs)
goto fail;
}
stackp--; /* discard greedy flag */
- options = (int)*--stackp;
+ options = (long)*--stackp;
d = *--stackp;
p = *--stackp;
/* Restore register info. */
@@ -3412,7 +3412,7 @@ re_search(bufp, string, size, startpos, range, regs)
*stackp++ = pattern_place; \
*stackp++ = string_place; \
- *stackp++ = (unsigned char*)options; /* current option status */ \
+ *stackp++ = (unsigned char*)(long)options; /* current option status */ \
*stackp++ = (unsigned char*)0; /* non-greedy flag */ \
} while(0)